Structs
- HTMLA
Element Props - HTML
Address Element Props - HTML
Article Element Props - HTML
Aside Element Props - HTML
Audio Element Props - HTML
Base Element Props - HTML
BdiElement Props - HTML
BdoElement Props - HTML
Blockquote Element Props - HTML
Body Element Props - HTML
BrElement Props - HTML
Button Element Props - HTML
Canvas Element Props - HTML
Circle Element Props - HTML
Cite Element Props - HTML
DdElement Props - HTML
Defs Element Props - HTML
Details Element Props - HTML
DfnElement Props - HTML
Dialog Element Props - HTML
DivElement Props - HTML
DlElement Props - HTML
DtElement Props - HTML
Ellipse Element Props - HTML
EmElement Props - HTML
Figcaption Element Props - HTML
Figure Element Props - HTML
Footer Element Props - HTML
Foreign Object Element Props - HTML
Form Element Props - HTMLG
Element Props - HTML
H1Element Props - HTML
H2Element Props - HTML
H3Element Props - HTML
H4Element Props - HTML
H5Element Props - HTML
H6Element Props - HTML
Head Element Props - HTML
Header Element Props - HTML
HrElement Props - HTML
Html Element Props - HTMLI
Element Props - HTML
Iframe Element Props - HTML
ImgElement Props - HTML
Input Element Props - HTML
KbdElement Props - HTML
Label Element Props - HTML
Legend Element Props - HTML
LiElement Props - HTML
Line Element Props - HTML
Linear Gradient Element Props - HTML
Link Element Props - HTML
Main Element Props - HTML
Mark Element Props - HTML
Mask Element Props - HTML
Meta Element Props - HTML
Meter Element Props - HTML
NavElement Props - HTML
Noscript Element Props - HTML
OlElement Props - HTML
Optgroup Element Props - HTML
Option Element Props - HTML
Output Element Props - HTMLP
Element Props - HTML
Path Element Props - HTML
Polygon Element Props - HTML
Polyline Element Props - HTML
Progress Element Props - HTMLQ
Element Props - HTML
Radial Gradient Element Props - HTML
Rect Element Props - HTML
RpElement Props - HTML
RtElement Props - HTML
Ruby Element Props - HTMLS
Element Props - HTML
Samp Element Props - HTML
Script Element Props - HTML
Section Element Props - HTML
Select Element Props - HTML
Small Element Props - HTML
Source Element Props - HTML
Span Element Props - HTML
Stop Element Props - HTML
Strong Element Props - HTML
Style Element Props - HTML
SubElement Props - HTML
Summary Element Props - HTML
SupElement Props - HTML
SvgElement Props - HTML
Table Element Props - HTML
Tbody Element Props - HTML
TdElement Props - HTML
Template Element Props - HTML
Textarea Element Props - HTML
Tfoot Element Props - HTML
ThElement Props - HTML
Thead Element Props - HTML
Time Element Props - HTML
Title Element Props - HTML
TrElement Props - HTMLU
Element Props - HTML
UlElement Props - HTML
UseElement Props - HTML
VarElement Props - HTML
Video Element Props - HTML
WbrElement Props - a
- HTML
<a>element - Creates a hyperlink to other web pages or resources - address
- HTML
<address>element - Defines contact information for the author/owner of a document - article
- HTML
<article>element - Defines an independent, self-contained content - aside
- HTML
<aside>element - Defines content aside from the page content - audio
- HTML
<audio>element - Embeds sound content in the document - base
- HTML
<base>element - Specifies the base URL/target for all relative URLs in a document - bdi
- HTML
<bdi>element - Defines a term/name within a description list - bdo
- HTML
<bdo>element - Overrides the current text direction - blockquote
- HTML
<blockquote>element - Defines a section that is quoted from another source - body
- HTML
<body>element - Represents the content of an HTML document - br
- HTML
<br>element - Produces a line break in text - button
- HTML
<button>element - Clickable button control - canvas
- HTML
<canvas>element - Container for graphics rendered with JavaScript - circle
- HTML
<circle>element - Draws a circle in SVG - cite
- HTML
<cite>element - Defines the title of a work - dd
- HTML
<dd>element - Defines a description/value pair within a<dl>element - defs
- HTML
<defs>element - Container for reusable SVG elements - details
- HTML
<details>element - Defines additional details that the user can view or hide - dfn
- HTML
<dfn>element - Defines a definition - dialog
- HTML
<dialog>element - Defines a dialog box or other interactive component - div
- HTML
<div>element - Container element for grouping and styling content - dl
- HTML
<dl>element - Defines a description list - dt
- HTML
<dt>element - Defines a term/name in a description list - ellipse
- HTML
<ellipse>element - Draws an ellipse in SVG - em
- HTML
<em>element - Defines emphasized text - figcaption
- HTML
<figcaption>element - Defines a caption for a<figure>element - figure
- HTML
<figure>element - Specifies self-contained content, like illustrations, diagrams, photos, code listings, etc. - footer
- HTML
<footer>element - Defines a footer for a document or section - foreign
Object - HTML
element - Includes non-SVG elements inside SVG - form
- HTML
<form>element - Container for interactive inputs to collect user data - g
- HTML
<g>element - Groups SVG elements together - h1
- HTML
element - First level heading (most important)
- h2
- HTML
element - Second level heading
- h3
- HTML
element - Third level heading
- h4
- HTML
element - Fourth level heading
- h5
- HTML
element - Fifth level heading
- h6
- HTML
element - Sixth level heading (least important)
- head
- HTML
<head>element - Contains metadata about the document - header
- HTML
<header>element - Defines a container for introductory content or a set of navigational links - hr
- HTML
<hr>element - Creates a horizontal rule (divider) - html
- HTML
<html>element - Root element of an HTML document - i
- HTML
<i>element - Defines a part of text in an alternate voice or mood - iframe
- HTML
<iframe>element - Embeds another document within the current HTML document - img
- HTML
<img>element - Embeds an image into the document - input
- HTML
<input>element - Creates interactive controls for forms - kbd
- HTML
<kbd>element - Defines keyboard input - label
- HTML
<label>element - Caption for a form control - legend
- HTML
<legend>element - Defines a caption for a<fieldset>element - li
- HTML
<li>element - List item within ordered or unordered lists - line
- HTML
<line>element - Draws a line in SVG - linear
Gradient - HTML
element - Defines a linear gradient for SVG fills - link
- HTML
<link>element - Specifies relationships between the current document and an external resource - main
- HTML
<main>element - Specifies the main content of a document - mark
- HTML
<mark>element - Defines marked/highlighted text - mask
- HTML
<mask>element - Defines an area where SVG elements are partially or fully hidden - meta
- HTML
<metaelement - Provides metadata about the document - meter
- HTML
<meter>element - Defines a scalar measurement within a known range (a gauge) - nav
- HTML
<nav>element - Defines navigation links - noscript
- HTML
<noscript>element - Defines content that is displayed to users with disabled scripts - ol
- HTML
<ol>element - Ordered (numbered) list - optgroup
- HTML
<optgroup>element - Defines a group of related<option>elements in a<select>element - option
- HTML
<option>element - Defines option in a select dropdown - output
- HTML
<output>element - Defines the result of a calculation - p
- HTML
<p>element - Represents a paragraph of text - path
- HTML
<path>element - Defines a path in SVG graphics - polygon
- HTML
<polygon>element - Draws a closed shape with straight lines in SVG - polyline
- HTML
<polyline>element - Draws connected straight lines in SVG - progress
- HTML
<progress>element - Defines the progress of a task - q
- HTML
<q>element - Defines a short inline quotation - radial
Gradient - HTML
element - Defines a radial gradient for SVG fills - rect
- HTML
<rect>element - Draws a rectangle in SVG - rp
- HTML
<rp>element - Defines a parenthesis for browsers that do not support<ruby> - rt
- HTML
<rt>element - Defines a ruby text - ruby
- HTML
<ruby>element - Defines a ruby annotation (for East Asian typography) - s
- HTML
<s>element - Defines strikethrough text - samp
- HTML
<samp>element - Defines sample output from a computer program - script
- HTML
<script>element - Embeds executable code or data - section
- HTML
<section>element - Defines a section in a document - select
- HTML
<select>element - Dropdown selection list - small
- HTML
<small>element - Defines smaller text - source
- HTML
<source>element - Defines media resources for video/audio elements - span
- HTML
<span>element - Inline container for targeting text with styles - stop
- HTML
<stop>element - Defines color transitions in gradients - strong
- HTML
<strong>element - Defines important text - style
- HTML
<style>element - Defines style information for a document - sub
- HTML
<sub>element - Defines subscript text - summary
- HTML
<summary>element - Defines a visible heading for a<details>element - sup
- HTML
<sup>element - Defines superscript text - svg
- HTML
<svg>element - Container for SVG graphics - table
- HTML
<table>element - Creates a data table with rows and columns - tbody
- HTML
<tbody>element - Groups body content in a table - td
- HTML
<td>element - Table data cell - template
- HTML
<template>element - Defines a container for content that is not to be rendered when a page is loaded - textarea
- HTML
<textarea>element - Multi-line text input control - tfoot
- HTML
<tfoot>element - Groups footer content in a table - th
- HTML
<th>element - Table header cell - thead
- HTML
<thead>element - Groups header content in a table - time
- HTML
<time>element - Defines a date/time - title
- HTML
<title>element - Defines the title of the document - tr
- HTML
<tr>element - Table row container - u
- HTML
<u>element - Defines text that should be rendered as underlined - ul
- HTML
<ul>element - Unordered list with bullet points - use
- HTML
<use>element - Reuses an SVG element defined elsewhere - var
- HTML
<var>element - Defines a variable - video
- HTML
<video>element - Embeds video content in the document - wbr
- HTML
<wbr>element - Inserts a line break opportunity